/**
 * @file        用户认证控制器（试运行）
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 提供基础登录接口，集成JWT签发与参数校验，业务逻辑分离到service
 */

import { Elysia } from 'elysia';
import { jwtPlugin } from '@/plugins/jwt';
import { loginBodySchema, type LoginBody } from '@/validators/try/auth.validator';
import { loginResponse200Schema, loginResponse400Schema } from '@/validators/try/auth.response';
import { loginService } from '@/services/try/auth.service';

/**
 * 登录接口
 * @param app Elysia实例
 * @returns Elysia实例（带登录路由）
 */
export const authController = new Elysia()
    .use(jwtPlugin)
    .post('/api/login', ({ body, jwt, set }: { body: LoginBody; jwt: any; set: any }) => loginService(body, jwt, set), {
        body: loginBodySchema,
        detail: {
            tags: ['认证'],
            summary: '用户登录',
            description: '基础登录接口，用户名/密码校验通过后返回JWT',
        },
        response: {
            200: loginResponse200Schema,
            400: loginResponse400Schema,
        },
    });
