/**
 * @file        受保护接口控制器（试运行）
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 提供需要JWT认证的受保护接口，业务逻辑分离到service
 */

import { Elysia } from 'elysia';
import { jwtAuthPlugin } from '@/plugins/jwt-auth';
import { protectedResponse200Schema, protectedResponse401Schema } from '@/validators/try/protected.response';
import { protectedService } from '@/services/try/protected.service';

/**
 * 受保护接口
 * @param app Elysia实例
 * @returns Elysia实例（带受保护路由）
 */
export const protectedController = new Elysia()
    .use(jwtAuthPlugin)
    .get('/api/protected', ({ user }: any) => protectedService(user), {
        detail: {
            summary: '受保护接口',
            tags: ['认证'],
            description: '需要JWT认证的受保护接口，返回当前用户信息',
            security: [{ bearerAuth: [] }],
        },
        response: {
            200: protectedResponse200Schema,
            401: protectedResponse401Schema,
        },
    });
