/**
 * @file        用户认证参数校验规则
 * @author      hotok
 * @date        2025-06-28
 * @lastEditor  hotok
 * @lastEditTime 2025-06-28
 * @description 登录接口参数校验规则，含中文错误提示
 */

import { t } from 'elysia';
import type { Static } from 'elysia';

/**
 * 登录请求参数校验规则
 * @property {string} username - 用户名，最少3位
 * @property {string} password - 密码，最少6位
 */
export const loginBodySchema = t.Object({
    username: t.String({ minLength: 2, maxLength: 16 }),
    password: t.String({ minLength: 6, maxLength: 32 }),
});

export type LoginBody = Static<typeof loginBodySchema>;
